labeltools.label_vertical_moments_in_expr_with_diatonic_intervals
=================================================================

.. autofunction:: abjad.tools.labeltools.label_vertical_moments_in_expr_with_diatonic_intervals.label_vertical_moments_in_expr_with_diatonic_intervals
   :noindex:
